package com.ruoyi.frequency.orderevaluate.service;

import java.math.BigDecimal;
import java.util.List;
import com.ruoyi.frequency.orderevaluate.entity.OrderEvaluate;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.vo.UserVo;

/**
 * 订单评价Service接口
 * 
 * @author zj
 * @date 2023-10-13
 */
public interface OrderEvaluateService extends IService<OrderEvaluate>
{
    /**
     * 查询订单评价
     * 
     * @param id 订单评价主键
     * @return 订单评价
     */
    public OrderEvaluate selectOrderEvaluateById(Long id);

    /**
     * 查询订单评价列表
     * 
     * @param orderEvaluate 订单评价
     * @return 订单评价集合
     */
    public List<OrderEvaluate> selectOrderEvaluateList(OrderEvaluate orderEvaluate);

    /**
     * 新增订单评价
     * 
     * @param orderEvaluate 订单评价
     * @return 结果
     */
    public int insertOrderEvaluate(OrderEvaluate orderEvaluate);

    /**
     * 修改订单评价
     * 
     * @param orderEvaluate 订单评价
     * @return 结果
     */
    public int updateOrderEvaluate(OrderEvaluate orderEvaluate);

    /**
     * 批量删除订单评价
     * 
     * @param ids 需要删除的订单评价主键集合
     * @return 结果
     */
    public int deleteOrderEvaluateByIds(Long[] ids);

    /**
     * 删除订单评价信息
     * 
     * @param id 订单评价主键
     * @return 结果
     */
    public int deleteOrderEvaluateById(Long id);


    /**
     * 计算评分
     * @param evaluateUserVo
     * @return
     */
    BigDecimal getUserStar(UserVo evaluateUserVo);
}
